Module: Git

Defined in:
lib/github_helper/git.rb

Overview

This is a little hack to the Git gem to add a way to check the staged files And also to forcepush a branch.

Defined Under Namespace

Classes: Base, Lib, Status