Class: Git::Status
- Inherits:
-
Object
- Object
- Git::Status
- Defined in:
- lib/github_helper/git.rb
Instance Method Summary collapse
-
#staged ⇒ Object
A file about to be commited has a type and a sha_index.
Instance Method Details
#staged ⇒ Object
A file about to be commited has a type and a sha_index
8 9 10 |
# File 'lib/github_helper/git.rb', line 8 def staged @files.select { |k, f| f.sha_index != "0000000000000000000000000000000000000000" && f.type != nil } end |